unit X2H_Main;

interface

uses
  SysUtils, Classes, Controls, Forms, Dialogs, StdCtrls, ExtCtrls, ComCtrls,
  X2H_XML, OleCtrls, SHDocVw, ActiveX;

type
  TForm1 = class(TForm)
    OpenXMLDialog: TOpenDialog;
    Panel1: TPanel;
    Splitter1: TSplitter;
    Panel2: TPanel;
    LoadXMLButton: TButton;
    XMLMemo: TMemo;
    Label1: TLabel;
    Label2: TLabel;
    SaveHTMLButton: TButton;
    ConvertButton: TButton;
    Label3: TLabel;
    StatusBar1: TStatusBar;
    SaveHTMLDialog: TSaveDialog;
    Panel3: TPanel;
    HTMLMemo: TMemo;
    Splitter2: TSplitter;
    WebBrowser: TWebBrowser;
    procedure LoadXMLButtonClick(Sender: TObject);
    procedure ConvertButtonClick(Sender: TObject);
    procedure SaveHTMLButtonClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    procedure ShowHTML(sHTML: WideString);
  public
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

procedure TForm1.FormCreate(Sender: TObject);
begin
  WebBrowser.DoubleBuffered := true;
  HTMLMemo.DoubleBuffered := true;
  XMLMemo.DoubleBuffered := true;
  Panel1.DoubleBuffered := true;
end;

procedure TForm1.LoadXMLButtonClick(Sender: TObject);
begin
  if not OpenXMLDialog.Execute then exit;
  try
    XMLMemo.Lines.LoadFromFile(OpenXMLDialog.FileName);
    SaveHTMLDialog.FileName:=ChangeFileExt(OpenXMLDialog.FileName, '.htm');
  except
    ShowMessage('Unable to load the XML file.');
  end;
end;

procedure TForm1.SaveHTMLButtonClick(Sender: TObject);
begin
  if not SaveHTMLDialog.Execute then exit;
  try
    HTMLMemo.Lines.SaveToFile(SaveHTMLDialog.FileName);
  except
    ShowMessage('Unable to save the HTML file.');
  end;
end;

procedure TForm1.ConvertButtonClick(Sender: TObject);
var
  XML2HTML: TXML2HTML;
  ws: WideString;
begin
  HTMLMemo.Clear;
  XML2HTML := TXML2HTML.Create;
  try
    if XML2HTML.ParseXML(trim(XMLMemo.Text)) then begin
      ws := XML2HTML.GetAsHTML;
      HTMLMemo.Text := ws;
      ShowHTML(ws);
    end
    else ShowMessage('XML error. The XML source must be well-formed.');
  finally
    XML2HTML.Free;
  end;
end;

procedure TForm1.ShowHTML(sHTML: WideString);
var
  MemoryStream: TMemoryStream;
begin
  WebBrowser.Navigate('about:blank') ;
  while WebBrowser.ReadyState < READYSTATE_INTERACTIVE do Application.ProcessMessages;
  if Assigned(WebBrowser.Document) then begin
    MemoryStream := TMemoryStream.Create;
    try
      MemoryStream.WriteBuffer(Pointer(sHTML)^, length(sHTML) * sizeof(WideChar));
      MemoryStream.Seek(0, 0) ;
      (WebBrowser.Document as IPersistStreamInit).Load(TStreamAdapter.Create(MemoryStream)) ;
    finally
      MemoryStream.Free;
    end;
  end;
end;

end.
